package com.ruixuan.launch.service;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ruixuan.common.core.domain.ResultResponse;
import com.ruixuan.launch.entity.KuaishouLaunchTargetTemplate;

import java.util.List;

/**
 * 账户下所属定向信息Service接口
 *
 * @author ruoyi
 * @date 2022-07-05
 */
public interface IKuaishouLaunchTargetTemplateService {
    /**
     * 查询账户下所属定向信息
     *
     * @param id 账户下所属定向信息主键
     * @return 账户下所属定向信息
     */
    public KuaishouLaunchTargetTemplate selectKuaishouLaunchTargetTemplateById(Long id);

    /**
     * 查询账户下所属定向信息列表
     *
     * @param kuaishouLaunchTargetTemplate 账户下所属定向信息
     * @return 账户下所属定向信息集合
     */
    public List<KuaishouLaunchTargetTemplate> selectKuaishouLaunchTargetTemplateList(KuaishouLaunchTargetTemplate kuaishouLaunchTargetTemplate);

    /**
     * 新增账户下所属定向信息
     *
     * @param kuaishouLaunchTargetTemplate 账户下所属定向信息
     * @return 结果
     */
    public ResultResponse insertKuaishouLaunchTargetTemplate(JSONObject request);

    /**
     * 修改账户下所属定向信息
     *
     * @param kuaishouLaunchTargetTemplate 账户下所属定向信息
     * @return 结果
     */
    public int updateKuaishouLaunchTargetTemplate(KuaishouLaunchTargetTemplate kuaishouLaunchTargetTemplate);

    /**
     * 批量删除账户下所属定向信息
     *
     * @param ids 需要删除的账户下所属定向信息主键集合
     * @return 结果
     */
    public int deleteKuaishouLaunchTargetTemplateByIds(Long[] ids);

    /**
     * 删除账户下所属定向信息信息
     *
     * @param id 账户下所属定向信息主键
     * @return 结果
     */
    public int deleteKuaishouLaunchTargetTemplateById(Long id);

    JSONObject getTargetJson(Long targetId, JSONObject strategyJson);

    ResultResponse selectKuaishouLaunchTargetTemplateByIds(String ids);

    ResultResponse insertMore(JSONObject request);
}